from odin_messages.base import BaseEventMessage


class NewLimitOrderMessage(BaseEventMessage):
    exchange: str
    market_code: str
    limit_price: str
    quantity: float
    usd_price: float
    price_delta: float
    selling: bool


class NewSpotOrderMessage(BaseEventMessage):
    exchange: str
    order_id: str
    market_code: str
    quantity: float
    usd_price: float
    selling: bool


class CancelOrderMessage(BaseEventMessage):
    order_id: str
    exchange: str
    market_code: str


class UpdateOrderMessage(BaseEventMessage):
    order_id: str
    market_code: str
    exchange: str
    new_limit_price: float
    new_quantity: float



from typing import Dict

from odin_messages.balance import CoinBalance
from odin_messages.base import BaseEventMessage

class NewOpenOrderMessage(BaseEventMessage):
    exchange: str
    order_id: str
    market_code: str
    amount: int
    type: str
    selling: str
    status: str


class CanceledOrderMessage(BaseEventMessage):
    exchange: str
    order_id: str
    status: str
    market_code: str
    type: str
    selling: str


class OrderFilledMessage(BaseEventMessage):
    exchange: str
    order_id: str
    status: str
    market_code: str
    type: str
    selling: str
    amount: float
    filled: float
    remaining: float


class WalletBalanceUpdate(BaseEventMessage):
    exchange: str
    currency_code: str
    balance: float
    used_balance: float

class FirstBalance(BaseEventMessage):
    exchange: str
    coins: Dict[str, CoinBalance]

